@@ -12,6 +12,7 @@ mod observation;
 
 pub mod epoch;
 pub mod record;
+pub mod hatanaka;
 pub mod constellation;
 
 use thiserror::Error;
@@ -19,13 +20,13 @@ use std::str::FromStr;
 
 #[macro_export]
 /// Returns `true` if given `Rinex` line is a comment
-macro_rules! is_rinex_comment {
+macro_rules! is_comment {
     ($line: expr) => { $line.contains("COMMENT") };
 }
 
 /// Describes all known `RINEX` file types
 #[derive(Copy, Clone, PartialEq, Debug)]
-pub enum RinexType {
+pub enum Type {
     /// Describes Observation Data (OBS),
     /// Phase & Pseudo range measurements
     ObservationData, 
@@ -37,43 +38,43 @@ pub enum RinexType {
 }
 
 #[derive(Error, Debug)]
-/// `RinexType` related errors
-pub enum RinexTypeError {
+/// `Type` related errors
+pub enum TypeError {
     #[error("Unknown RINEX type identifier \"{0}\"")]
     UnknownType(String),
 }
 
-impl Default for RinexType {
-    /// Builds a default `RinexType`
-    fn default() -> RinexType { RinexType::ObservationData }
+impl Default for Type {
+    /// Builds a default `Type`
+    fn default() -> Type { Type::ObservationData }
 }
 
-impl RinexType {
+impl Type {
     /// Converts `Self` to str
     pub fn to_str (&self) -> &str {
         match *self {
-            RinexType::ObservationData => "ObservationData",
-            RinexType::NavigationMessage => "NavigationMessage",
-            RinexType::MeteorologicalData => "MeteorologicalData",
+            Type::ObservationData => "ObservationData",
+            Type::NavigationMessage => "NavigationMessage",
+            Type::MeteorologicalData => "MeteorologicalData",
         }
     }
     /// Converts `Self` to string
     pub fn to_string (&self) -> String { String::from(self.to_str()) }
 }
 
-impl std::str::FromStr for RinexType {
-    type Err = RinexTypeError;
+impl std::str::FromStr for Type {
+    type Err = TypeError;
     fn from_str (s: &str) -> Result<Self, Self::Err> {
         if s.eq("NAVIGATION DATA") {
-            Ok(RinexType::NavigationMessage)
+            Ok(Type::NavigationMessage)
         } else if s.contains("NAV DATA") {
-            Ok(RinexType::NavigationMessage)
+            Ok(Type::NavigationMessage)
         } else if s.eq("OBSERVATION DATA") {
-            Ok(RinexType::ObservationData)
+            Ok(Type::ObservationData)
         } else if s.eq("METEOROLOGICAL DATA") {
-            Ok(RinexType::MeteorologicalData)
+            Ok(Type::MeteorologicalData)
         } else {
-            Err(RinexTypeError::UnknownType(String::from(s)))
+            Err(TypeError::UnknownType(String::from(s)))
         }
     }
 }
@@ -82,7 +83,7 @@ impl std::str::FromStr for RinexType {
 #[derive(Debug)]
 pub struct Rinex {
     pub header: header::RinexHeader,
-    pub record: record::Record,
+    pub record: Option<record::Record>,
 }
 
 impl Default for Rinex {
@@ -90,7 +91,7 @@ impl Default for Rinex {
     fn default() -> Rinex {
         Rinex {
             header: header::RinexHeader::default(),
-            record: record::Record::default(), 
+            record: None, 
         }
     }
 }
@@ -103,12 +104,12 @@ pub enum RinexError {
     #[error("Header parsing error")]
     HeaderError(#[from] header::Error),
     #[error("Rinex type error")]
-    TypeError(#[from] RinexTypeError),
+    TypeError(#[from] TypeError),
 }
 
 impl Rinex {
     /// Builds a new `RINEX` struct from given:
-    pub fn new (header: header::RinexHeader, record: record::Record) -> Rinex {
+    pub fn new (header: header::RinexHeader, record: Option<record::Record>) -> Rinex {
         Rinex {
             header,
             record,
@@ -134,11 +135,11 @@ impl Rinex {
     //    -> &std::collections::HashMap<String, record::RecordItem> { &self.record[nth] }
 
     /// Retruns true if this is an NAV rinex
-    pub fn is_navigation_rinex (&self) -> bool { self.header.rinex_type == RinexType::NavigationMessage }
+    pub fn is_navigation_rinex (&self) -> bool { self.header.rinex_type == Type::NavigationMessage }
     /// Retruns true if this is an OBS rinex
-    pub fn is_observation_rinex (&self) -> bool { self.header.rinex_type == RinexType::ObservationData }
+    pub fn is_observation_rinex (&self) -> bool { self.header.rinex_type == Type::ObservationData }
     /// Returns true if this is a METEO rinex
-    pub fn is_meteo_rinex (&self) -> bool { self.header.rinex_type == RinexType::MeteorologicalData }
+    pub fn is_meteo_rinex (&self) -> bool { self.header.rinex_type == Type::MeteorologicalData }
 
     /// Builds a `Rinex` from given file.
     /// Input file must respect the whitespace specifications
@@ -146,12 +147,12 @@ impl Rinex {
     /// The header section must respect the labelization standard too.
     pub fn from_file (fp: &std::path::Path) -> Result<Rinex, RinexError> {
         let (header, body) = Rinex::split_rinex_content(fp)?;
-        let hd = header::RinexHeader::from_str(&header)?;
-        let rec = record::build_record(&hd, &body)?;
-        Ok(Rinex{
-            header: hd,
-            record: rec,
-        })
+        let header = header::RinexHeader::from_str(&header)?;
+        let record : Option<record::Record> = match header.is_crinex() {
+            false => Some(record::build_record(&header,&body)?),
+            true => None,
+        };
+        Ok(Rinex { header, record })
     }
 }
 
