@@ -5,9 +5,10 @@ use std::collections::HashMap;
 
 use crate::header;
 use crate::navigation;
+use crate::observation;
 use crate::epoch::Epoch;
-use crate::is_rinex_comment;
-use crate::{RinexType, RinexTypeError};
+use crate::is_comment;
+use crate::{Type, TypeError};
 use crate::constellation::Constellation;
 
 /// ̀`Sv` describes a Satellite Vehiculee
@@ -102,13 +103,6 @@ impl Record {
     }
 }
 
-impl Default for Record {
-    fn default() -> Record {
-        let r : HashMap<Epoch, HashMap<Sv, HashMap<String, ComplexEnum>>> = HashMap::new();
-        Record::NavRecord(r)
-    }
-}
-
 #[derive(Error, Debug)]
 pub enum RecordError {
     #[error("record parsing not supported for type \"{0}\"")]
@@ -122,7 +116,7 @@ fn block_record_start (line: &str, header: &header::RinexHeader) -> bool {
     match header.version.major < 4 {
         true => {
             match &header.rinex_type {
-                RinexType::NavigationMessage => {
+                Type::NavigationMessage => {
                     let known_sv_identifiers: &'static [char] = 
                         &['R','G','E','B','J','C','S']; 
                     match &header.constellation {
@@ -140,7 +134,7 @@ fn block_record_start (line: &str, header: &header::RinexHeader) -> bool {
                         }
                     }
                 },
-                RinexType::ObservationData => parsed.len() > 8,
+                Type::ObservationData => parsed.len() > 8,
                 _ => false, 
             }
         },
@@ -159,11 +153,11 @@ fn block_record_start (line: &str, header: &header::RinexHeader) -> bool {
     }
 }
 
-pub fn build_record (header: &header::RinexHeader, body: &str) -> Result<Record, RinexTypeError> { 
+pub fn build_record (header: &header::RinexHeader, body: &str) -> Result<Record, TypeError> { 
     let mut body = body.lines();
     let mut line = body.next()
         .unwrap();
-    while is_rinex_comment!(line) {
+    while is_comment!(line) {
         line = body.next()
             .unwrap()
     }
@@ -177,9 +171,16 @@ pub fn build_record (header: &header::RinexHeader, body: &str) -> Result<Record,
         let is_new_block = block_record_start(&line, &header);
         if is_new_block && !first {
             match &header.rinex_type {
-                RinexType::NavigationMessage => {
+                Type::NavigationMessage => {
                     if let Ok((e, sv, map)) = navigation::build_record_entry(&header, &block) {
-                        let mut smap : HashMap<Sv, HashMap<String, ComplexEnum>> = HashMap::with_capacity(10);
+                        let mut smap : HashMap<Sv, HashMap<String, ComplexEnum>> = HashMap::with_capacity(1);
+                        smap.insert(sv, map);
+                        rec.insert(e, smap);
+                    }
+                },
+                Type::ObservationData => {
+                    if let Ok((e, sv, map)) = observation::build_record_entry(&header, &block) {
+                        let mut smap : HashMap<Sv, HashMap<String, ComplexEnum>> = HashMap::with_capacity(1);
                         smap.insert(sv, map);
                         rec.insert(e, smap);
                     }
@@ -204,7 +205,7 @@ pub fn build_record (header: &header::RinexHeader, body: &str) -> Result<Record,
             break
         }
 
-        while is_rinex_comment!(line) {
+        while is_comment!(line) {
             if let Some(l) = body.next() {
                 line = l
             } else {
@@ -218,9 +219,9 @@ pub fn build_record (header: &header::RinexHeader, body: &str) -> Result<Record,
         }
     }
     match &header.rinex_type {
-        RinexType::NavigationMessage => Ok(Record::NavRecord(rec)), 
-        RinexType::ObservationData => Ok(Record::ObsRecord(rec)), 
-        _ => Err(RinexTypeError::UnknownType(header.rinex_type.to_string())),
+        Type::NavigationMessage => Ok(Record::NavRecord(rec)), 
+        Type::ObservationData => Ok(Record::ObsRecord(rec)), 
+        _ => Err(TypeError::UnknownType(header.rinex_type.to_string())),
     }
 }
 
@@ -264,4 +265,28 @@ impl ComplexEnum {
             _ => Err(ComplexEnumError::UnknownTypeDescriptor(desc.to_string())),
         }
     }
+    pub fn as_f32 (&self) -> Option<f32> {
+        match self {
+            ComplexEnum::F32(f) => Some(f.clone()),
+            _ => None,
+        }
+    }
+    pub fn as_f64 (&self) -> Option<f64> {
+        match self {
+            ComplexEnum::F64(f) => Some(f.clone()),
+            _ => None,
+        }
+    }
+    pub fn as_str (&self) -> Option<String> {
+        match self {
+            ComplexEnum::Str(s) => Some(s.clone()),
+            _ => None,
+        }
+    }
+    pub fn as_u8 (&self) -> Option<u8> {
+        match self {
+            ComplexEnum::U8(u) => Some(u.clone()),
+            _ => None,
+        }
+    }
 }
